@@ -236,7 +236,10 @@ class Room:
             self.threat = self.random_threat_no_traps(self.cr, room_name=self.name)
         self.door = self._doors.front_linear()
         self.exit = self._exits.front_linear()
-        self.xp = self.threat.xp if self.threat.xp else 0
+        if hasattr(self.threat, 'xp'):
+            self.xp = self.threat.xp
+        else:
+            self.xp = 0
 
     def __repr__(self):
         self.output = (
@@ -260,7 +263,7 @@ class WildArea(Room):
         (10, random_city_npc),
         (1, random_dungeon_npc),
         (1, random_trap),
-    ), flat=False)
+    ))
 
     def __repr__(self):
         return f"{self.threat}"
